==> 1.0.59.tar.gz: lib/modules/account/user_repo.dart <==
import 'package:b2b_graphql_package/GraphQLConfiguration.dart';
import 'package:b2b_graphql_package/modules/account/user_address_model.dart';
import 'package:graphql_flutter/graphql_flutter.dart';
import 'user_model.dart';

class UserRepo {
  var graphQLConfiguration;

  var userDetails;
  var userAddressDetails = [];
  var billingAddressDetails;
  UserRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }
  // Future<bool> addUser(UserModel userModel) async {
  //   String addUserGql =
  //       """mutation addUser( \$sdgsdg: String,\$lastName: String,\$mobileNumber: Float,
  //       \$email: String,\$pwd: String) {
  //                       addUser(userInput:{firstName: \$sdgsdg,
  //                 lastName: \$lastName,
  //                 mobileNumber:\$mobileNumber,
  //                 email:\$email,
  //                 pwd:\$pwd})
  //                               {
  //                                 id
  //                               }
  //                   }""";
  //   GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
  //   GraphQLClient _client = graphQLConfiguration.clientToQuery();
  //   final vble = {
  //     "sdgsdg": userModel.firstName,
  //     "lastName": userModel.lastName
  //   };
  //   QueryResult result = await _client.mutate(
  //     MutationOptions(
  //       document: gql(addUserGql),
  //       variables: vble,
  //     ),
  //   );
  //   if (!result.hasException) {
  //     return true;
  //   }
  //   return false;
  // }

  Future getUserById(String id) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var getUserByIdGql = """ 
                query getByUserId(\$id: String) {
                getByUserId(id: \$id) {
                  _id
                  contactName
                  companyName
                  mobileNumber
                  emailId
                  altMobileNumber
                  __typename
                }
              }

            """;

    final vble = {
      "id": id,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(getUserByIdGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    try {
      if (!result.hasException) {
        var userDetailsModel = result.data!['getByUserId'];

        if (userDetailsModel != null && userDetailsModel.length > 0) {
          userDetails = userByIdFromJson(userDetailsModel);
          return userDetails;
        }
      }
      return userDetails;
    } catch (e) {
      print(e);
      return userDetails;
    }
  }

  Future getUserByAddress(String id) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var getUserByAddressGql = """ 
                query getByUserIdAddress(\$id: String) {
                getByUserIdAddress(id: \$id) {
                  _id
                  companyName
                  contactName
                  emailId
                  address
                  mobileNumber
                  pinCode
                  country
                  state
                  city
                  billingAddress
                  __typename
                }
              }

            """;

    final vble = {
      "id": id,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(getUserByAddressGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    try {
      if (!result.hasException) {
        var userAddressDetailsModel = result.data!['getByUserIdAddress'];

        if (userAddressDetailsModel != null &&
            userAddressDetailsModel.length > 0) {
          userAddressDetails = userByAddressFromJson(userAddressDetailsModel);
          return userAddressDetails;
        }
      }
      return userAddressDetails;
    } catch (e) {
      print(e);
      return userAddressDetails;
    }
  }

  Future<bool> updateBillingAddress(
      UpdateBillingAddressRequestModel userAddressModel) async {
    String addUserGql = """mutation updateBillingAddress(
                \$id: String
                \$addressId: String
                \$addressInput: AddressInput
              ) {
                updateBillingAddress(
                  id: \$id
                  addressId: \$addressId
                  addressInput:\$addressInput
                ) {
                  _id
                  __typename
                }
              }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "addressId": userAddressModel.addressId,
      "addressInput": userAddressModel.addressInput,
      "id": userAddressModel.sId
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var updateBillingAddress = result.data!['updateBillingAddress'];
      if (updateBillingAddress != null && updateBillingAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future<bool> removeAddress(
      UpdateAddAddressRequestModel userAddressModel) async {
    String addUserGql =
        """mutation removeAddress(\$id: String, \$addressId: String) {
              removeAddress(id: \$id, addressId: \$addressId) {
                _id
                __typename
              }
            }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "addressId": userAddressModel.addressId,
      "id": userAddressModel.sId
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var removeAddress = result.data!['removeAddress'];
      if (removeAddress != null && removeAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future<bool> updateAddress(
      UpdateAddAddressRequestModel userAddressModel) async {
    String addUserGql = """mutation updateAddress(
                      \$id: String
                      \$addressId: String
                      \$addressInput: AddressInput
                    ) {
                      updateAddress(id: \$id, addressId: \$addressId, addressInput: \$addressInput) {
                        _id
                        __typename
                      }
                    }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "addressId": userAddressModel.addressId,
      "addressInput": userAddressModel.addressInput,
      "id": userAddressModel.sId
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var updateAddress = result.data!['updateAddress'];
      if (updateAddress != null && updateAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future<bool> addAddress(UpdateAddAddressRequestModel userAddressModel) async {
    String addUserGql =
        """mutation addAddress(\$id: String, \$addressInput: AddressInput) {
                    addAddress(id: \$id, addressInput: \$addressInput) {
                      _id
                      companyName
                      contactName
                      emailId
                      mobileNumber
                      address
                      pinCode
                      country
                      state
                      city
                      billingAddress
                      __typename
                    }
                  }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "addressInput": userAddressModel.addressInput,
      "id": userAddressModel.sId
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var addAddress = result.data!['addAddress'];
      if (addAddress != null && addAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future<bool> updateUserProfile(
      UpdateUserProfileRequest userProfileModel) async {
    String addUserGql =
        """mutation updateUserProfile(\$id: String, \$userInput: UserInput!) {
                updateUserProfile(id: \$id, userInput: \$userInput) {
                  _id
                  contactName
                  companyName
                  mobileNumber
                  emailId
                  altMobileNumber
                  gstNumber
                  __typename
                }
              }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "userInput": userProfileModel.userInput,
      "id": userProfileModel.id
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var addAddress = result.data!['updateUserProfile'];
      if (addAddress != null && addAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future getBillingAddress(String id) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var getBillingAddressGql = """ 
                query getByUserIdBillingAddress(\$id: String) {
              getByUserIdBillingAddress(id: \$id) {
                _id
                companyName
                contactName
                emailId
                mobileNumber
                address
                pinCode
                country
                state
                city
                billingAddress
                __typename
              }
            }

            """;

    final vble = {
      "id": id,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(getBillingAddressGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    try {
      if (!result.hasException) {
        var userBillingAddress = result.data!['getByUserIdBillingAddress'];

        if (userBillingAddress != null) {
          billingAddressDetails =
              userBillingAddressFromJson(userBillingAddress);
          return billingAddressDetails;
        }
      }
      return billingAddressDetails;
    } catch (e) {
      print(e);
      return billingAddressDetails;
    }
  }
}

==> 1.0.104.tar.gz: lib/modules/account/user_repo.dart <==
import 'package:b2b_graphql_package/GraphQLConfiguration.dart';
import 'package:b2b_graphql_package/modules/account/user_address_model.dart';
import 'package:graphql_flutter/graphql_flutter.dart';
import 'user_model.dart';

class UserRepo {
  var graphQLConfiguration;

  var userDetails;
  var userAddressDetails = [];
  var billingAddressDetails;
  UserRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }
  // Future<bool> addUser(UserModel userModel) async {
  //   String addUserGql =
  //       """mutation addUser( \$sdgsdg: String,\$lastName: String,\$mobileNumber: Float,
  //       \$email: String,\$pwd: String) {
  //                       addUser(userInput:{firstName: \$sdgsdg,
  //                 lastName: \$lastName,
  //                 mobileNumber:\$mobileNumber,
  //                 email:\$email,
  //                 pwd:\$pwd})
  //                               {
  //                                 id
  //                               }
  //                   }""";
  //   GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
  //   GraphQLClient _client = graphQLConfiguration.clientToQuery();
  //   final vble = {
  //     "sdgsdg": userModel.firstName,
  //     "lastName": userModel.lastName
  //   };
  //   QueryResult result = await _client.mutate(
  //     MutationOptions(
  //       document: gql(addUserGql),
  //       variables: vble,
  //     ),
  //   );
  //   if (!result.hasException) {
  //     return true;
  //   }
  //   return false;
  // }

  Future getUserById(String id) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var getUserByIdGql = """ 
                query getByUserId(\$id: String) {
                getByUserId(id: \$id) {
                  _id
                  contactName
                  mobileNumber
                  firstName
                  lastName
                  isdCode
                  altIsdCode
                  emailId
                  companyName
                  altMobileNumber
                  gstNumber
                }
              }

            """;

    final vble = {
      "id": id,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(getUserByIdGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    try {
      if (!result.hasException) {
        var userDetailsModel = result.data!['getByUserId'];

        if (userDetailsModel != null && userDetailsModel.length > 0) {
          userDetails = userDetailsFromJson(userDetailsModel);
          return userDetails;
        }
      }
      return userDetails;
    } catch (e) {
      print(e);
      return userDetails;
    }
  }

  Future getUserByAddress(String id) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var getUserByAddressGql = """ 
                query getByUserIdAddress(\$id: String) {
                getByUserIdAddress(id: \$id) {
                  _id
                  companyName
                  contactName
                  emailId
                  address
                  mobileNumber
                  pinCode
                  country
                  state
                  city
                  billingAddress
                  __typename
                }
              }

            """;

    final vble = {
      "id": id,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(getUserByAddressGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    try {
      if (!result.hasException) {
        var userAddressDetailsModel = result.data!['getByUserIdAddress'];

        if (userAddressDetailsModel != null &&
            userAddressDetailsModel.length > 0) {
          userAddressDetails = userByAddressFromJson(userAddressDetailsModel);
          return userAddressDetails;
        }
      }
      return userAddressDetails;
    } catch (e) {
      print(e);
      return userAddressDetails;
    }
  }

  Future<bool> updateBillingAddress(
      UpdateBillingAddressRequestModel userAddressModel) async {
    String addUserGql = """mutation updateBillingAddress(
                \$id: String
                \$addressId: String
                \$addressInput: AddressInput
              ) {
                updateBillingAddress(
                  id: \$id
                  addressId: \$addressId
                  addressInput:\$addressInput
                ) {
                  _id
                  __typename
                }
              }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "addressId": userAddressModel.addressId,
      "addressInput": userAddressModel.addressInput,
      "id": userAddressModel.sId
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var updateBillingAddress = result.data!['updateBillingAddress'];
      if (updateBillingAddress != null && updateBillingAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future<bool> removeAddress(
      UpdateAddAddressRequestModel userAddressModel) async {
    String addUserGql =
        """mutation removeAddress(\$id: String, \$addressId: String) {
              removeAddress(id: \$id, addressId: \$addressId) {
                _id
                __typename
              }
            }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "addressId": userAddressModel.addressId,
      "id": userAddressModel.sId
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var removeAddress = result.data!['removeAddress'];
      if (removeAddress != null && removeAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future<bool> updateAddress(
      UpdateAddAddressRequestModel userAddressModel) async {
    String addUserGql = """mutation updateAddress(
                      \$id: String
                      \$addressId: String
                      \$addressInput: AddressInput
                    ) {
                      updateAddress(id: \$id, addressId: \$addressId, addressInput: \$addressInput) {
                        _id
                        __typename
                      }
                    }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "addressId": userAddressModel.addressId,
      "addressInput": userAddressModel.addressInput,
      "id": userAddressModel.sId
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var updateAddress = result.data!['updateAddress'];
      if (updateAddress != null && updateAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future<bool> addAddress(UpdateAddAddressRequestModel userAddressModel) async {
    String addUserGql =
        """mutation addAddress(\$id: String, \$addressInput: AddressInput) {
                    addAddress(id: \$id, addressInput: \$addressInput) {
                      _id
                      companyName
                      contactName
                      emailId
                      mobileNumber
                      address
                      pinCode
                      country
                      state
                      city
                      billingAddress
                      __typename
                    }
                  }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "addressInput": userAddressModel.addressInput,
      "id": userAddressModel.sId
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var addAddress = result.data!['addAddress'];
      if (addAddress != null && addAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future<bool> updateUserProfile(
      UpdateUserProfileRequest userProfileModel) async {
    String addUserGql = """
              mutation updateUserProfile(\$id: String, \$userInput: UserInput!) {
                updateUserProfile(id: \$id, userInput: \$userInput) {
                  _id
                  contactName
                  companyName
                  mobileNumber
                  emailId
                  altMobileNumber
                  gstNumber
                  firstName
                  lastName
                  altIsdCode
                }
              }
              """;
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {
      "userInput": userProfileModel.userInput,
      "id": userProfileModel.id
    };
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var addAddress = result.data!['updateUserProfile'];
      if (addAddress != null && addAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future<bool> updateUserIdPassword(
      String id, UpdateUserPassword userPasswordModel) async {
    String addUserGql = """
              mutation updateUserIdPassword(\$id: String, \$userInput: UserInput!) {
              updateUserIdPassword(id: \$id, userInput: \$userInput) {
                _id
              }
            }

              """;
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {"userInput": userPasswordModel, "id": id};
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(addUserGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var addAddress = result.data!['updateUserIdPassword'];
      if (addAddress != null && addAddress["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future getBillingAddress(String id) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var getBillingAddressGql = """ 
                query getByUserIdBillingAddress(\$id: String) {
              getByUserIdBillingAddress(id: \$id) {
                _id
                companyName
                contactName
                emailId
                mobileNumber
                address
                pinCode
                country
                state
                city
                billingAddress
                __typename
              }
            }

            """;

    final vble = {
      "id": id,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(getBillingAddressGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    try {
      if (!result.hasException) {
        var userBillingAddress = result.data!['getByUserIdBillingAddress'];

        if (userBillingAddress != null) {
          billingAddressDetails =
              userBillingAddressFromJson(userBillingAddress);
          return billingAddressDetails;
        }
      }
      return billingAddressDetails;
    } catch (e) {
      print(e);
      return billingAddressDetails;
    }
  }

  Future updateReseller(String id, UserBankDetailModel detail) async {
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    print('started');
    String updateResellerDetail = """ 
                mutation updateResellerDetail(\$id: String, \$detail: UserBankDetailInput) {
                updateResellerDetail(id: \$id, detail: \$detail) {
                _id
                companyName
                contactName
                firstName
                lastName
                isdCode
                altIsdCode
                mobileNumber
                altMobileNumber
                emailId
                password
                gstNumber
                userType
                bankDetail {
                  accountHolderName
                  accountNumber
                  ifscCode
                }
                }
              }

            """;

    final vble = {"id": id, "detail": detail};
    QueryResult result = await _client.mutate(MutationOptions(
      document: gql(updateResellerDetail),
      variables: vble,
    ));
    print(result);
    try {
      if (!result.hasException) {
        var userDetailsModel = result.data!['updateResellerDetail'];

        if (userDetailsModel != null && userDetailsModel.length > 0) {
          userDetails = userBankDetailFromJson(userDetailsModel!['bankDetail']);
          return userDetails;
        }
      }
      return userDetails;
    } catch (e) {
      print(e);
      return userDetails;
    }
  }

  Future getUserBankDetails(String id) async {
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    String getUserBankDetails = """ 
                query getUserBankDetails(\$id: String) {
                getUserBankDetails(id: \$id) {
                _id
                userType
                bankDetail {
                  accountHolderName
                  accountNumber
                  ifscCode
                }
                }
              }

            """;

    final vble = {"id": id};
    QueryResult result = await _client.query(QueryOptions(
        document: gql(getUserBankDetails),
        variables: vble,
        fetchPolicy: FetchPolicy.networkOnly));
    try {
      if (!result.hasException) {
        var userDetailsModel = result.data!['getUserBankDetails'];
        print(userDetailsModel);
        if (userDetailsModel != null) {
          userDetails = userBankDetailFromJson(userDetailsModel!['bankDetail']);
          return userDetails;
        }
      }
      return userDetails;
    } catch (e) {
      print(e);
      return userDetails;
    }
  }
}
